@@ -2,7 +2,6 @@ from graphql import GraphQLError as GraphQLCoreError
 
 
 class GraphQLError(GraphQLCoreError):
-
     def __init__(
         self,
         message,
@@ -11,7 +10,7 @@ class GraphQLError(GraphQLCoreError):
         positions=None,
         path=None,
         original_error=None,
-        extensions=None
+        extensions=None,
     ):
         super(GraphQLError, self).__init__(
             message=message,
@@ -20,6 +19,6 @@ class GraphQLError(GraphQLCoreError):
             positions=positions,
             path=path,
             original_error=original_error,
-            extensions=extensions
+            extensions=extensions,
         )
         self.extensions = extensions
